@@ -579,24 +579,27 @@ class TerraformTemplateParser(TemplateParser):
         groups = re.findall(r'[.a-zA-Z]+[(].*[,].*[)]', param_str, re.I)
         if groups:
             for group in groups:
-                updated_group, processed = self.process_resource(group, count)
-                if processed:
-                    param_str = param_str.replace(group, str(updated_group))
+                if group != param_str:
+                    updated_group, processed = self.process_resource(group, count)
+                    if processed:
+                        param_str = param_str.replace(group, str(updated_group))
 
         groups = re.findall(r'^[(].*[,].*[)]|.* ([(].*[)])', param_str, re.I)
         if groups:
             for group in groups:
-                parameter_str = re.findall("(?<=\().*(?=\))", group)[0]
-                updated_group = self.process_expression_parameters(parameter_str, count)
-                param_str = param_str.replace(group, str(updated_group))
+                if group != param_str:
+                    parameter_str = re.findall("(?<=\().*(?=\))", group)[0]
+                    updated_group = self.process_expression_parameters(parameter_str, count)
+                    param_str = param_str.replace(group, str(updated_group))
 
         # groups = re.findall(r'(?<=\?)([a-z0-9A-Z._\-\s]*(\?){1}[a-z0-9A-Z._\-\s]*(\:){1}[a-z0-9A-Z._\-\s]*)(?=:)', param_str, re.I)
         groups = re.findall(r'(?<=\?\s)(.*[?].*[:].*)(?=\s:)', param_str, re.I)
         if groups:
             for group in groups:
-                updated_group, processed = self.process_resource(group, count)
-                if processed:
-                    param_str = param_str.replace(group, str(updated_group))
+                if group != param_str:
+                    updated_group, processed = self.process_resource(group, count)
+                    if processed:
+                        param_str = param_str.replace(group, str(updated_group))
         return param_str
 
     def eval_expression(self, resource):
@@ -863,10 +866,11 @@ class TerraformTemplateParser(TemplateParser):
                     if groups:
                         i = 0
                         for group in groups:
-                            updated_group, _ = self.process_resource(groups[i], count)
-                            string_params["group%s" % (str(i))] = updated_group
-                            parameter_str = parameter_str.replace(group, "group%s" % (str(i)))
-                            i+=1
+                            if group != parameter_str:
+                                updated_group, _ = self.process_resource(groups[i], count)
+                                string_params["group%s" % (str(i))] = updated_group
+                                parameter_str = parameter_str.replace(group, "group%s" % (str(i)))
+                                i+=1
                     
                     # params = re.findall(r"[a-zA-Z0-9.()\[\]_*\"]+|(?:(?![a-zA-Z0-9.()\[\]_*\"]).)+", parameter_str)
                     params = re.findall(r"[a-zA-Z0-9.()\[\],-_*\"\'\{\$\}]+|(?:(?![ a-zA-Z0-9.()\[\]_*\"\'\{\$\}]).)+", parameter_str)
